CommitType

Enum CommitType 

pub enum CommitType {
    Breaking,
    Feature,
    Bugfix,
    Other,
    Meta,
}
A specific commit type

Variants



Breaking



Feature



Bugfix



Other



Meta

Implementations

Source

impl CommitType

pub fn first_variant() -> CommitType

Return the first commit type (Breaking)

pub fn last_variant() -> CommitType

Return the last commit variant (Meta)

pub fn next_variant(&self) -> Option<CommitType>

Given a commit type, return the next commit type

pub fn prev_variant(&self) -> Option<CommitType>

Given a commit type, return the previous commit type

pub fn iter_variants() -> CommitTypeIterator

Return an iterator over all commit types

Examples found in repository?
examples/usage.rs (line 8)
5fn main() {
6    println!("The emoji commit types are:");
7
8    for commit_type in CommitType::iter_variants() {
9        println!("{}  - {}", commit_type.emoji(), commit_type.description());
10    }
11}
pub fn emoji(&self) -> &'static str

Return the emoji for this commit type

Examples found in repository?
examples/usage.rs (line 9)
5fn main() {
6    println!("The emoji commit types are:");
7
8    for commit_type in CommitType::iter_variants() {
9        println!("{}  - {}", commit_type.emoji(), commit_type.description());
10    }
11}
pub fn bump_level(&self) -> BumpLevel

Return the bump level for this commit type

pub fn description(&self) -> &'static str

Return the description for this commit type

Examples found in repository?
examples/usage.rs (line 9)
5fn main() {
6    println!("The emoji commit types are:");
7
8    for commit_type in CommitType::iter_variants() {
9        println!("{}  - {}", commit_type.emoji(), commit_type.description());
10    }
11}